# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HardwareStatusChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'location_id': 'str',
        'location_name': 'str',
        'location_abbreviation': 'str',
        'hardware_count': 'int',
        'unassigned_count': 'int',
        'online_count': 'int',
        'offline_count': 'int'
    }

    attribute_map = {
        'location_id': 'LocationId',
        'location_name': 'LocationName',
        'location_abbreviation': 'LocationAbbreviation',
        'hardware_count': 'HardwareCount',
        'unassigned_count': 'UnassignedCount',
        'online_count': 'OnlineCount',
        'offline_count': 'OfflineCount'
    }

    def __init__(self, location_id=None, location_name=None, location_abbreviation=None, hardware_count=None, unassigned_count=None, online_count=None, offline_count=None):  # noqa: E501
        """HardwareStatusChild - a model defined in Swagger"""  # noqa: E501
        self._location_id = None
        self._location_name = None
        self._location_abbreviation = None
        self._hardware_count = None
        self._unassigned_count = None
        self._online_count = None
        self._offline_count = None
        self.discriminator = None
        if location_id is not None:
            self.location_id = location_id
        if location_name is not None:
            self.location_name = location_name
        if location_abbreviation is not None:
            self.location_abbreviation = location_abbreviation
        if hardware_count is not None:
            self.hardware_count = hardware_count
        if unassigned_count is not None:
            self.unassigned_count = unassigned_count
        if online_count is not None:
            self.online_count = online_count
        if offline_count is not None:
            self.offline_count = offline_count

    @property
    def location_id(self):
        """Gets the location_id of this HardwareStatusChild.  # noqa: E501


        :return: The location_id of this HardwareStatusChild.  # noqa: E501
        :rtype: str
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """Sets the location_id of this HardwareStatusChild.


        :param location_id: The location_id of this HardwareStatusChild.  # noqa: E501
        :type: str
        """

        self._location_id = location_id

    @property
    def location_name(self):
        """Gets the location_name of this HardwareStatusChild.  # noqa: E501


        :return: The location_name of this HardwareStatusChild.  # noqa: E501
        :rtype: str
        """
        return self._location_name

    @location_name.setter
    def location_name(self, location_name):
        """Sets the location_name of this HardwareStatusChild.


        :param location_name: The location_name of this HardwareStatusChild.  # noqa: E501
        :type: str
        """

        self._location_name = location_name

    @property
    def location_abbreviation(self):
        """Gets the location_abbreviation of this HardwareStatusChild.  # noqa: E501


        :return: The location_abbreviation of this HardwareStatusChild.  # noqa: E501
        :rtype: str
        """
        return self._location_abbreviation

    @location_abbreviation.setter
    def location_abbreviation(self, location_abbreviation):
        """Sets the location_abbreviation of this HardwareStatusChild.


        :param location_abbreviation: The location_abbreviation of this HardwareStatusChild.  # noqa: E501
        :type: str
        """

        self._location_abbreviation = location_abbreviation

    @property
    def hardware_count(self):
        """Gets the hardware_count of this HardwareStatusChild.  # noqa: E501


        :return: The hardware_count of this HardwareStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._hardware_count

    @hardware_count.setter
    def hardware_count(self, hardware_count):
        """Sets the hardware_count of this HardwareStatusChild.


        :param hardware_count: The hardware_count of this HardwareStatusChild.  # noqa: E501
        :type: int
        """

        self._hardware_count = hardware_count

    @property
    def unassigned_count(self):
        """Gets the unassigned_count of this HardwareStatusChild.  # noqa: E501


        :return: The unassigned_count of this HardwareStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._unassigned_count

    @unassigned_count.setter
    def unassigned_count(self, unassigned_count):
        """Sets the unassigned_count of this HardwareStatusChild.


        :param unassigned_count: The unassigned_count of this HardwareStatusChild.  # noqa: E501
        :type: int
        """

        self._unassigned_count = unassigned_count

    @property
    def online_count(self):
        """Gets the online_count of this HardwareStatusChild.  # noqa: E501


        :return: The online_count of this HardwareStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._online_count

    @online_count.setter
    def online_count(self, online_count):
        """Sets the online_count of this HardwareStatusChild.


        :param online_count: The online_count of this HardwareStatusChild.  # noqa: E501
        :type: int
        """

        self._online_count = online_count

    @property
    def offline_count(self):
        """Gets the offline_count of this HardwareStatusChild.  # noqa: E501


        :return: The offline_count of this HardwareStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._offline_count

    @offline_count.setter
    def offline_count(self, offline_count):
        """Sets the offline_count of this HardwareStatusChild.


        :param offline_count: The offline_count of this HardwareStatusChild.  # noqa: E501
        :type: int
        """

        self._offline_count = offline_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HardwareStatusChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HardwareStatusChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
