# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.alerts_api import AlertsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestAlertsApi(unittest.TestCase):
    """AlertsApi unit test stubs"""

    def setUp(self):
        self.api = AlertsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_acknowledge_alerts(self):
        """Test case for acknowledge_alerts

        Acknowledges all alerts for the supplied groups  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
