# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MonitoringPointCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'abbreviation': 'str',
        'parent_id': 'str',
        'bearing_id': 'str',
        'monitoring_point_type_code': 'MonitoringPointTypeCodesForApi',
        'running_speed_multiplier': 'float',
        'note': 'str'
    }

    attribute_map = {
        'name': 'Name',
        'abbreviation': 'Abbreviation',
        'parent_id': 'ParentId',
        'bearing_id': 'BearingId',
        'monitoring_point_type_code': 'MonitoringPointTypeCode',
        'running_speed_multiplier': 'RunningSpeedMultiplier',
        'note': 'Note'
    }

    def __init__(self, name=None, abbreviation=None, parent_id=None, bearing_id=None, monitoring_point_type_code=None, running_speed_multiplier=1, note=None):  # noqa: E501
        """MonitoringPointCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._abbreviation = None
        self._parent_id = None
        self._bearing_id = None
        self._monitoring_point_type_code = None
        self._running_speed_multiplier = None
        self._note = None
        self.discriminator = None
        self.name = name
        if abbreviation is not None:
            self.abbreviation = abbreviation
        self.parent_id = parent_id
        if bearing_id is not None:
            self.bearing_id = bearing_id
        self.monitoring_point_type_code = monitoring_point_type_code
        if running_speed_multiplier is not None:
            self.running_speed_multiplier = running_speed_multiplier
        if note is not None:
            self.note = note

    @property
    def name(self):
        """Gets the name of this MonitoringPointCreateRequest.  # noqa: E501


        :return: The name of this MonitoringPointCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MonitoringPointCreateRequest.


        :param name: The name of this MonitoringPointCreateRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def abbreviation(self):
        """Gets the abbreviation of this MonitoringPointCreateRequest.  # noqa: E501


        :return: The abbreviation of this MonitoringPointCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._abbreviation

    @abbreviation.setter
    def abbreviation(self, abbreviation):
        """Sets the abbreviation of this MonitoringPointCreateRequest.


        :param abbreviation: The abbreviation of this MonitoringPointCreateRequest.  # noqa: E501
        :type: str
        """

        self._abbreviation = abbreviation

    @property
    def parent_id(self):
        """Gets the parent_id of this MonitoringPointCreateRequest.  # noqa: E501


        :return: The parent_id of this MonitoringPointCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this MonitoringPointCreateRequest.


        :param parent_id: The parent_id of this MonitoringPointCreateRequest.  # noqa: E501
        :type: str
        """
        if parent_id is None:
            raise ValueError("Invalid value for `parent_id`, must not be `None`")  # noqa: E501

        self._parent_id = parent_id

    @property
    def bearing_id(self):
        """Gets the bearing_id of this MonitoringPointCreateRequest.  # noqa: E501


        :return: The bearing_id of this MonitoringPointCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._bearing_id

    @bearing_id.setter
    def bearing_id(self, bearing_id):
        """Sets the bearing_id of this MonitoringPointCreateRequest.


        :param bearing_id: The bearing_id of this MonitoringPointCreateRequest.  # noqa: E501
        :type: str
        """

        self._bearing_id = bearing_id

    @property
    def monitoring_point_type_code(self):
        """Gets the monitoring_point_type_code of this MonitoringPointCreateRequest.  # noqa: E501


        :return: The monitoring_point_type_code of this MonitoringPointCreateRequest.  # noqa: E501
        :rtype: MonitoringPointTypeCodesForApi
        """
        return self._monitoring_point_type_code

    @monitoring_point_type_code.setter
    def monitoring_point_type_code(self, monitoring_point_type_code):
        """Sets the monitoring_point_type_code of this MonitoringPointCreateRequest.


        :param monitoring_point_type_code: The monitoring_point_type_code of this MonitoringPointCreateRequest.  # noqa: E501
        :type: MonitoringPointTypeCodesForApi
        """
        if monitoring_point_type_code is None:
            raise ValueError("Invalid value for `monitoring_point_type_code`, must not be `None`")  # noqa: E501

        self._monitoring_point_type_code = monitoring_point_type_code

    @property
    def running_speed_multiplier(self):
        """Gets the running_speed_multiplier of this MonitoringPointCreateRequest.  # noqa: E501


        :return: The running_speed_multiplier of this MonitoringPointCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._running_speed_multiplier

    @running_speed_multiplier.setter
    def running_speed_multiplier(self, running_speed_multiplier):
        """Sets the running_speed_multiplier of this MonitoringPointCreateRequest.


        :param running_speed_multiplier: The running_speed_multiplier of this MonitoringPointCreateRequest.  # noqa: E501
        :type: float
        """

        self._running_speed_multiplier = running_speed_multiplier

    @property
    def note(self):
        """Gets the note of this MonitoringPointCreateRequest.  # noqa: E501


        :return: The note of this MonitoringPointCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this MonitoringPointCreateRequest.


        :param note: The note of this MonitoringPointCreateRequest.  # noqa: E501
        :type: str
        """

        self._note = note

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MonitoringPointCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MonitoringPointCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
