# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.locations_api import LocationsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestLocationsApi(unittest.TestCase):
    """LocationsApi unit test stubs"""

    def setUp(self):
        self.api = LocationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_location(self):
        """Test case for create_location

        Creates a new location  # noqa: E501
        """
        pass

    def test_generate_location_api_key(self):
        """Test case for generate_location_api_key

        Generates a new API key for the specified location, replacing the existing one  # noqa: E501
        """
        pass

    def test_get_baseline_indicators_for_location(self):
        """Test case for get_baseline_indicators_for_location

        Gets a list of valid baselines for a given location  # noqa: E501
        """
        pass

    def test_get_location(self):
        """Test case for get_location

        Gets a specific location  # noqa: E501
        """
        pass

    def test_get_location_roi(self):
        """Test case for get_location_roi

        Gets ROI information for a location  # noqa: E501
        """
        pass

    def test_get_locations(self):
        """Test case for get_locations

        Returns a paged list of all locations that the user has access to  # noqa: E501
        """
        pass

    def test_update_location(self):
        """Test case for update_location

        Updates the specified location  # noqa: E501
        """
        pass

    def test_update_location_permissions(self):
        """Test case for update_location_permissions

        Updates the feature-permissions for the specified location  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
