from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from smart_diagnostics_client.api.activity_events_api import ActivityEventsApi
from smart_diagnostics_client.api.alerts_api import AlertsApi
from smart_diagnostics_client.api.analytics_api import AnalyticsApi
from smart_diagnostics_client.api.assets_api import AssetsApi
from smart_diagnostics_client.api.base_stations_api import BaseStationsApi
from smart_diagnostics_client.api.bearings_api import BearingsApi
from smart_diagnostics_client.api.board_ticket_statuses_api import BoardTicketStatusesApi
from smart_diagnostics_client.api.board_tickets_api import BoardTicketsApi
from smart_diagnostics_client.api.bulletins_api import BulletinsApi
from smart_diagnostics_client.api.corporations_api import CorporationsApi
from smart_diagnostics_client.api.dashboards_api import DashboardsApi
from smart_diagnostics_client.api.documents_api import DocumentsApi
from smart_diagnostics_client.api.events_api import EventsApi
from smart_diagnostics_client.api.files_api import FilesApi
from smart_diagnostics_client.api.filters_api import FiltersApi
from smart_diagnostics_client.api.groups_api import GroupsApi
from smart_diagnostics_client.api.hardware_events_api import HardwareEventsApi
from smart_diagnostics_client.api.hardware_status_api import HardwareStatusApi
from smart_diagnostics_client.api.hubs_api import HubsApi
from smart_diagnostics_client.api.identity_providers_api import IdentityProvidersApi
from smart_diagnostics_client.api.indicator_groups_api import IndicatorGroupsApi
from smart_diagnostics_client.api.indicators_api import IndicatorsApi
from smart_diagnostics_client.api.installs_api import InstallsApi
from smart_diagnostics_client.api.locations_api import LocationsApi
from smart_diagnostics_client.api.markers_api import MarkersApi
from smart_diagnostics_client.api.monitoring_point_type_codes_api import MonitoringPointTypeCodesApi
from smart_diagnostics_client.api.monitoring_points_api import MonitoringPointsApi
from smart_diagnostics_client.api.nodes_api import NodesApi
from smart_diagnostics_client.api.pictures_api import PicturesApi
from smart_diagnostics_client.api.properties_api import PropertiesApi
from smart_diagnostics_client.api.receivers_api import ReceiversApi
from smart_diagnostics_client.api.repeaters_api import RepeatersApi
from smart_diagnostics_client.api.reports_api import ReportsApi
from smart_diagnostics_client.api.sensors_api import SensorsApi
from smart_diagnostics_client.api.sessions_api import SessionsApi
from smart_diagnostics_client.api.setup_tools_api import SetupToolsApi
from smart_diagnostics_client.api.sub_systems_api import SubSystemsApi
from smart_diagnostics_client.api.systems_api import SystemsApi
from smart_diagnostics_client.api.tags_api import TagsApi
from smart_diagnostics_client.api.thermal_cameras_api import ThermalCamerasApi
from smart_diagnostics_client.api.tokens_api import TokensApi
from smart_diagnostics_client.api.tree_items_api import TreeItemsApi
from smart_diagnostics_client.api.user_permission_api import UserPermissionApi
from smart_diagnostics_client.api.users_api import UsersApi
