# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.bulletins_api import BulletinsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestBulletinsApi(unittest.TestCase):
    """BulletinsApi unit test stubs"""

    def setUp(self):
        self.api = BulletinsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_bulletin(self):
        """Test case for create_bulletin

        Creates a bulletin  # noqa: E501
        """
        pass

    def test_delete_bulletin(self):
        """Test case for delete_bulletin

        Deletes a bulletin  # noqa: E501
        """
        pass

    def test_get_bulletin(self):
        """Test case for get_bulletin

        Gets a specific bulletin  # noqa: E501
        """
        pass

    def test_get_bulletins(self):
        """Test case for get_bulletins

        Gets bulletins  # noqa: E501
        """
        pass

    def test_update_bulletin(self):
        """Test case for update_bulletin

        Updates a bulletin  # noqa: E501
        """
        pass

    def test_update_bulletin_image(self):
        """Test case for update_bulletin_image

        Updates a bulletin's image  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
