# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SystemUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'abbreviation': 'str',
        'is_paused': 'bool',
        'description': 'str',
        'is_visible': 'bool',
        'active': 'bool',
        'cds_master_system_ids': 'list[str]',
        'cds_base_station_ids': 'list[int]'
    }

    attribute_map = {
        'name': 'Name',
        'abbreviation': 'Abbreviation',
        'is_paused': 'IsPaused',
        'description': 'Description',
        'is_visible': 'IsVisible',
        'active': 'Active',
        'cds_master_system_ids': 'CdsMasterSystemIds',
        'cds_base_station_ids': 'CdsBaseStationIds'
    }

    def __init__(self, name=None, abbreviation=None, is_paused=None, description=None, is_visible=None, active=None, cds_master_system_ids=None, cds_base_station_ids=None):  # noqa: E501
        """SystemUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._abbreviation = None
        self._is_paused = None
        self._description = None
        self._is_visible = None
        self._active = None
        self._cds_master_system_ids = None
        self._cds_base_station_ids = None
        self.discriminator = None
        self.name = name
        if abbreviation is not None:
            self.abbreviation = abbreviation
        self.is_paused = is_paused
        if description is not None:
            self.description = description
        self.is_visible = is_visible
        self.active = active
        if cds_master_system_ids is not None:
            self.cds_master_system_ids = cds_master_system_ids
        if cds_base_station_ids is not None:
            self.cds_base_station_ids = cds_base_station_ids

    @property
    def name(self):
        """Gets the name of this SystemUpdateRequest.  # noqa: E501


        :return: The name of this SystemUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SystemUpdateRequest.


        :param name: The name of this SystemUpdateRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def abbreviation(self):
        """Gets the abbreviation of this SystemUpdateRequest.  # noqa: E501


        :return: The abbreviation of this SystemUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._abbreviation

    @abbreviation.setter
    def abbreviation(self, abbreviation):
        """Sets the abbreviation of this SystemUpdateRequest.


        :param abbreviation: The abbreviation of this SystemUpdateRequest.  # noqa: E501
        :type: str
        """

        self._abbreviation = abbreviation

    @property
    def is_paused(self):
        """Gets the is_paused of this SystemUpdateRequest.  # noqa: E501


        :return: The is_paused of this SystemUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_paused

    @is_paused.setter
    def is_paused(self, is_paused):
        """Sets the is_paused of this SystemUpdateRequest.


        :param is_paused: The is_paused of this SystemUpdateRequest.  # noqa: E501
        :type: bool
        """
        if is_paused is None:
            raise ValueError("Invalid value for `is_paused`, must not be `None`")  # noqa: E501

        self._is_paused = is_paused

    @property
    def description(self):
        """Gets the description of this SystemUpdateRequest.  # noqa: E501


        :return: The description of this SystemUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SystemUpdateRequest.


        :param description: The description of this SystemUpdateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def is_visible(self):
        """Gets the is_visible of this SystemUpdateRequest.  # noqa: E501


        :return: The is_visible of this SystemUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_visible

    @is_visible.setter
    def is_visible(self, is_visible):
        """Sets the is_visible of this SystemUpdateRequest.


        :param is_visible: The is_visible of this SystemUpdateRequest.  # noqa: E501
        :type: bool
        """
        if is_visible is None:
            raise ValueError("Invalid value for `is_visible`, must not be `None`")  # noqa: E501

        self._is_visible = is_visible

    @property
    def active(self):
        """Gets the active of this SystemUpdateRequest.  # noqa: E501


        :return: The active of this SystemUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this SystemUpdateRequest.


        :param active: The active of this SystemUpdateRequest.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def cds_master_system_ids(self):
        """Gets the cds_master_system_ids of this SystemUpdateRequest.  # noqa: E501


        :return: The cds_master_system_ids of this SystemUpdateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._cds_master_system_ids

    @cds_master_system_ids.setter
    def cds_master_system_ids(self, cds_master_system_ids):
        """Sets the cds_master_system_ids of this SystemUpdateRequest.


        :param cds_master_system_ids: The cds_master_system_ids of this SystemUpdateRequest.  # noqa: E501
        :type: list[str]
        """

        self._cds_master_system_ids = cds_master_system_ids

    @property
    def cds_base_station_ids(self):
        """Gets the cds_base_station_ids of this SystemUpdateRequest.  # noqa: E501


        :return: The cds_base_station_ids of this SystemUpdateRequest.  # noqa: E501
        :rtype: list[int]
        """
        return self._cds_base_station_ids

    @cds_base_station_ids.setter
    def cds_base_station_ids(self, cds_base_station_ids):
        """Sets the cds_base_station_ids of this SystemUpdateRequest.


        :param cds_base_station_ids: The cds_base_station_ids of this SystemUpdateRequest.  # noqa: E501
        :type: list[int]
        """

        self._cds_base_station_ids = cds_base_station_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SystemUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
