# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.systems_api import SystemsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestSystemsApi(unittest.TestCase):
    """SystemsApi unit test stubs"""

    def setUp(self):
        self.api = SystemsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_system(self):
        """Test case for create_system

        Creates a system  # noqa: E501
        """
        pass

    def test_get_asset_status_summaries_for_system(self):
        """Test case for get_asset_status_summaries_for_system

        Gets asset status summary for a system  # noqa: E501
        """
        pass

    def test_get_asset_status_summaries_for_systems(self):
        """Test case for get_asset_status_summaries_for_systems

        Gets asset status summary for systems  # noqa: E501
        """
        pass

    def test_get_system(self):
        """Test case for get_system

        Gets a system  # noqa: E501
        """
        pass

    def test_get_system_overview(self):
        """Test case for get_system_overview

        Gets the system overview for a single system  # noqa: E501
        """
        pass

    def test_get_systems(self):
        """Test case for get_systems

        Gets systems  # noqa: E501
        """
        pass

    def test_get_systems_overview(self):
        """Test case for get_systems_overview

        Gets all system overviews  # noqa: E501
        """
        pass

    def test_update_system(self):
        """Test case for update_system

        Updates a system  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
