# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.indicators_api import IndicatorsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestIndicatorsApi(unittest.TestCase):
    """IndicatorsApi unit test stubs"""

    def setUp(self):
        self.api = IndicatorsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_burst_data_audio(self):
        """Test case for get_burst_data_audio

        Generates audio from Indicator burst data.  Only vibration Indicators are supported.  # noqa: E501
        """
        pass

    def test_get_indicator(self):
        """Test case for get_indicator

        Gets an indicator response  # noqa: E501
        """
        pass

    def test_get_indicator_alarm_state(self):
        """Test case for get_indicator_alarm_state

        Get the alarm state for a specific indicator  # noqa: E501
        """
        pass

    def test_get_indicator_statistics(self):
        """Test case for get_indicator_statistics

        Gets indicator statistics  # noqa: E501
        """
        pass

    def test_get_indicator_types(self):
        """Test case for get_indicator_types

        Gets indicator types  # noqa: E501
        """
        pass

    def test_get_indicators(self):
        """Test case for get_indicators

        Gets indicator responses  # noqa: E501
        """
        pass

    def test_get_indicators_alarm_state(self):
        """Test case for get_indicators_alarm_state

        Get the alarm state for a list of indicators  # noqa: E501
        """
        pass

    def test_get_measure_ofs_for_indicator(self):
        """Test case for get_measure_ofs_for_indicator

        Returns a list of measureOf values and their UI-friendly format  # noqa: E501
        """
        pass

    def test_get_options_for_indicator(self):
        """Test case for get_options_for_indicator

        Gets options for indicators  # noqa: E501
        """
        pass

    def test_get_statistics_for_indicator(self):
        """Test case for get_statistics_for_indicator

        Gets statistics for a specific indicator  # noqa: E501
        """
        pass

    def test_set_smart_alarms(self):
        """Test case for set_smart_alarms

        Calculates and sets smart alarms for the given indicator.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
