# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.dashboards_api import DashboardsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestDashboardsApi(unittest.TestCase):
    """DashboardsApi unit test stubs"""

    def setUp(self):
        self.api = DashboardsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_dashboard(self):
        """Test case for create_dashboard

        Creates a new dashboard  # noqa: E501
        """
        pass

    def test_delete_dashboard(self):
        """Test case for delete_dashboard

        Deletes a dashboard  # noqa: E501
        """
        pass

    def test_get_dashboard(self):
        """Test case for get_dashboard

        """
        pass

    def test_get_dashboard_templates(self):
        """Test case for get_dashboard_templates

        Gets dashboard templates  # noqa: E501
        """
        pass

    def test_get_dashboards(self):
        """Test case for get_dashboards

        Gets all dashboards available to the user  # noqa: E501
        """
        pass

    def test_update_dashboard(self):
        """Test case for update_dashboard

        Updates a dashboard  # noqa: E501
        """
        pass

    def test_update_dashboard_permissions(self):
        """Test case for update_dashboard_permissions

        Updates dashboard permissions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
