# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LocationSettingsChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'max_transport_interval': 'int',
        'max_vibration_update_interval': 'int',
        'max_oil_quality_update_interval': 'int',
        'opc_enabled': 'bool',
        'assign_filters_to_location': 'bool',
        'external_notification_type': 'ExternalNotificationType'
    }

    attribute_map = {
        'max_transport_interval': 'MaxTransportInterval',
        'max_vibration_update_interval': 'MaxVibrationUpdateInterval',
        'max_oil_quality_update_interval': 'MaxOilQualityUpdateInterval',
        'opc_enabled': 'OpcEnabled',
        'assign_filters_to_location': 'AssignFiltersToLocation',
        'external_notification_type': 'ExternalNotificationType'
    }

    def __init__(self, max_transport_interval=None, max_vibration_update_interval=None, max_oil_quality_update_interval=None, opc_enabled=None, assign_filters_to_location=None, external_notification_type=None):  # noqa: E501
        """LocationSettingsChild - a model defined in Swagger"""  # noqa: E501
        self._max_transport_interval = None
        self._max_vibration_update_interval = None
        self._max_oil_quality_update_interval = None
        self._opc_enabled = None
        self._assign_filters_to_location = None
        self._external_notification_type = None
        self.discriminator = None
        if max_transport_interval is not None:
            self.max_transport_interval = max_transport_interval
        if max_vibration_update_interval is not None:
            self.max_vibration_update_interval = max_vibration_update_interval
        if max_oil_quality_update_interval is not None:
            self.max_oil_quality_update_interval = max_oil_quality_update_interval
        if opc_enabled is not None:
            self.opc_enabled = opc_enabled
        if assign_filters_to_location is not None:
            self.assign_filters_to_location = assign_filters_to_location
        if external_notification_type is not None:
            self.external_notification_type = external_notification_type

    @property
    def max_transport_interval(self):
        """Gets the max_transport_interval of this LocationSettingsChild.  # noqa: E501


        :return: The max_transport_interval of this LocationSettingsChild.  # noqa: E501
        :rtype: int
        """
        return self._max_transport_interval

    @max_transport_interval.setter
    def max_transport_interval(self, max_transport_interval):
        """Sets the max_transport_interval of this LocationSettingsChild.


        :param max_transport_interval: The max_transport_interval of this LocationSettingsChild.  # noqa: E501
        :type: int
        """

        self._max_transport_interval = max_transport_interval

    @property
    def max_vibration_update_interval(self):
        """Gets the max_vibration_update_interval of this LocationSettingsChild.  # noqa: E501


        :return: The max_vibration_update_interval of this LocationSettingsChild.  # noqa: E501
        :rtype: int
        """
        return self._max_vibration_update_interval

    @max_vibration_update_interval.setter
    def max_vibration_update_interval(self, max_vibration_update_interval):
        """Sets the max_vibration_update_interval of this LocationSettingsChild.


        :param max_vibration_update_interval: The max_vibration_update_interval of this LocationSettingsChild.  # noqa: E501
        :type: int
        """

        self._max_vibration_update_interval = max_vibration_update_interval

    @property
    def max_oil_quality_update_interval(self):
        """Gets the max_oil_quality_update_interval of this LocationSettingsChild.  # noqa: E501


        :return: The max_oil_quality_update_interval of this LocationSettingsChild.  # noqa: E501
        :rtype: int
        """
        return self._max_oil_quality_update_interval

    @max_oil_quality_update_interval.setter
    def max_oil_quality_update_interval(self, max_oil_quality_update_interval):
        """Sets the max_oil_quality_update_interval of this LocationSettingsChild.


        :param max_oil_quality_update_interval: The max_oil_quality_update_interval of this LocationSettingsChild.  # noqa: E501
        :type: int
        """

        self._max_oil_quality_update_interval = max_oil_quality_update_interval

    @property
    def opc_enabled(self):
        """Gets the opc_enabled of this LocationSettingsChild.  # noqa: E501


        :return: The opc_enabled of this LocationSettingsChild.  # noqa: E501
        :rtype: bool
        """
        return self._opc_enabled

    @opc_enabled.setter
    def opc_enabled(self, opc_enabled):
        """Sets the opc_enabled of this LocationSettingsChild.


        :param opc_enabled: The opc_enabled of this LocationSettingsChild.  # noqa: E501
        :type: bool
        """

        self._opc_enabled = opc_enabled

    @property
    def assign_filters_to_location(self):
        """Gets the assign_filters_to_location of this LocationSettingsChild.  # noqa: E501


        :return: The assign_filters_to_location of this LocationSettingsChild.  # noqa: E501
        :rtype: bool
        """
        return self._assign_filters_to_location

    @assign_filters_to_location.setter
    def assign_filters_to_location(self, assign_filters_to_location):
        """Sets the assign_filters_to_location of this LocationSettingsChild.


        :param assign_filters_to_location: The assign_filters_to_location of this LocationSettingsChild.  # noqa: E501
        :type: bool
        """

        self._assign_filters_to_location = assign_filters_to_location

    @property
    def external_notification_type(self):
        """Gets the external_notification_type of this LocationSettingsChild.  # noqa: E501


        :return: The external_notification_type of this LocationSettingsChild.  # noqa: E501
        :rtype: ExternalNotificationType
        """
        return self._external_notification_type

    @external_notification_type.setter
    def external_notification_type(self, external_notification_type):
        """Sets the external_notification_type of this LocationSettingsChild.


        :param external_notification_type: The external_notification_type of this LocationSettingsChild.  # noqa: E501
        :type: ExternalNotificationType
        """

        self._external_notification_type = external_notification_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LocationSettingsChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LocationSettingsChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
