# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.nodes_api import NodesApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestNodesApi(unittest.TestCase):
    """NodesApi unit test stubs"""

    def setUp(self):
        self.api = NodesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_export_long_burst(self):
        """Test case for export_long_burst

        Gets a long burst export for a given node  # noqa: E501
        """
        pass

    def test_export_nodes(self):
        """Test case for export_nodes

        Requests Node export.  # noqa: E501
        """
        pass

    def test_get_node(self):
        """Test case for get_node

        Gets the requested node  # noqa: E501
        """
        pass

    def test_get_nodes(self):
        """Test case for get_nodes

        Gets a paginated list of the nodes to which a user has access  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
