# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.activity_events_api import ActivityEventsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestActivityEventsApi(unittest.TestCase):
    """ActivityEventsApi unit test stubs"""

    def setUp(self):
        self.api = ActivityEventsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_activity_event(self):
        """Test case for create_activity_event

        Create an activity event  # noqa: E501
        """
        pass

    def test_create_activity_event_category_relationship(self):
        """Test case for create_activity_event_category_relationship

        Create an activity event category relationship  # noqa: E501
        """
        pass

    def test_create_activity_event_relationship(self):
        """Test case for create_activity_event_relationship

        Create an activity event relationship  # noqa: E501
        """
        pass

    def test_delete_activity_event(self):
        """Test case for delete_activity_event

        Delete an activity event  # noqa: E501
        """
        pass

    def test_delete_activity_event_category_relationship(self):
        """Test case for delete_activity_event_category_relationship

        Delete an activity event category relationship  # noqa: E501
        """
        pass

    def test_delete_activity_event_relationship(self):
        """Test case for delete_activity_event_relationship

        Delete an activity event relationship  # noqa: E501
        """
        pass

    def test_get_activity_event(self):
        """Test case for get_activity_event

        Gets an activity event  # noqa: E501
        """
        pass

    def test_get_activity_event_categories(self):
        """Test case for get_activity_event_categories

        Gets activity event categories  # noqa: E501
        """
        pass

    def test_get_activity_event_category(self):
        """Test case for get_activity_event_category

        Gets an activity event category  # noqa: E501
        """
        pass

    def test_get_activity_event_category_fields(self):
        """Test case for get_activity_event_category_fields

        Get activity event category fields  # noqa: E501
        """
        pass

    def test_get_activity_event_category_relationship(self):
        """Test case for get_activity_event_category_relationship

        Gets an activity event category relationship  # noqa: E501
        """
        pass

    def test_get_activity_event_detail(self):
        """Test case for get_activity_event_detail

        Gets an activity event details. Expands on standard get activity event (by id) method  # noqa: E501
        """
        pass

    def test_get_activity_event_field_values(self):
        """Test case for get_activity_event_field_values

        Get activity event field values (if any)  # noqa: E501
        """
        pass

    def test_get_activity_event_relationship(self):
        """Test case for get_activity_event_relationship

        Gets an activity event relationship  # noqa: E501
        """
        pass

    def test_get_activity_event_subcategories(self):
        """Test case for get_activity_event_subcategories

        Get activity event subcategories  # noqa: E501
        """
        pass

    def test_get_activity_events(self):
        """Test case for get_activity_events

        Gets activity events  # noqa: E501
        """
        pass

    def test_get_hierarchy_activity_events_post(self):
        """Test case for get_hierarchy_activity_events_post

        Gets activity events for hierarchy groups  # noqa: E501
        """
        pass

    def test_update_activity_event(self):
        """Test case for update_activity_event

        Update an activity event  # noqa: E501
        """
        pass

    def test_update_activity_event_field_values(self):
        """Test case for update_activity_event_field_values

        Update / replace activity event field values list  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
