# coding: utf-8

# flake8: noqa

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from smart_diagnostics_client.api.activity_events_api import ActivityEventsApi
from smart_diagnostics_client.api.alerts_api import AlertsApi
from smart_diagnostics_client.api.analytics_api import AnalyticsApi
from smart_diagnostics_client.api.assets_api import AssetsApi
from smart_diagnostics_client.api.base_stations_api import BaseStationsApi
from smart_diagnostics_client.api.bearings_api import BearingsApi
from smart_diagnostics_client.api.board_ticket_statuses_api import BoardTicketStatusesApi
from smart_diagnostics_client.api.board_tickets_api import BoardTicketsApi
from smart_diagnostics_client.api.bulletins_api import BulletinsApi
from smart_diagnostics_client.api.corporations_api import CorporationsApi
from smart_diagnostics_client.api.dashboards_api import DashboardsApi
from smart_diagnostics_client.api.documents_api import DocumentsApi
from smart_diagnostics_client.api.events_api import EventsApi
from smart_diagnostics_client.api.files_api import FilesApi
from smart_diagnostics_client.api.filters_api import FiltersApi
from smart_diagnostics_client.api.groups_api import GroupsApi
from smart_diagnostics_client.api.hardware_events_api import HardwareEventsApi
from smart_diagnostics_client.api.hardware_status_api import HardwareStatusApi
from smart_diagnostics_client.api.hubs_api import HubsApi
from smart_diagnostics_client.api.identity_providers_api import IdentityProvidersApi
from smart_diagnostics_client.api.indicator_groups_api import IndicatorGroupsApi
from smart_diagnostics_client.api.indicators_api import IndicatorsApi
from smart_diagnostics_client.api.installs_api import InstallsApi
from smart_diagnostics_client.api.locations_api import LocationsApi
from smart_diagnostics_client.api.markers_api import MarkersApi
from smart_diagnostics_client.api.monitoring_point_type_codes_api import MonitoringPointTypeCodesApi
from smart_diagnostics_client.api.monitoring_points_api import MonitoringPointsApi
from smart_diagnostics_client.api.nodes_api import NodesApi
from smart_diagnostics_client.api.pictures_api import PicturesApi
from smart_diagnostics_client.api.properties_api import PropertiesApi
from smart_diagnostics_client.api.receivers_api import ReceiversApi
from smart_diagnostics_client.api.repeaters_api import RepeatersApi
from smart_diagnostics_client.api.reports_api import ReportsApi
from smart_diagnostics_client.api.sensors_api import SensorsApi
from smart_diagnostics_client.api.sessions_api import SessionsApi
from smart_diagnostics_client.api.setup_tools_api import SetupToolsApi
from smart_diagnostics_client.api.sub_systems_api import SubSystemsApi
from smart_diagnostics_client.api.systems_api import SystemsApi
from smart_diagnostics_client.api.tags_api import TagsApi
from smart_diagnostics_client.api.thermal_cameras_api import ThermalCamerasApi
from smart_diagnostics_client.api.tokens_api import TokensApi
from smart_diagnostics_client.api.tree_items_api import TreeItemsApi
from smart_diagnostics_client.api.user_permission_api import UserPermissionApi
from smart_diagnostics_client.api.users_api import UsersApi
# import ApiClient
from smart_diagnostics_client.api_client import ApiClient
from smart_diagnostics_client.configuration import Configuration
# import models into sdk package
from smart_diagnostics_client.models.acknowledged_alerts_response import AcknowledgedAlertsResponse
from smart_diagnostics_client.models.activity_event_assignment_child import ActivityEventAssignmentChild
from smart_diagnostics_client.models.activity_event_assignment_type import ActivityEventAssignmentType
from smart_diagnostics_client.models.activity_event_bind_child import ActivityEventBindChild
from smart_diagnostics_client.models.activity_event_bind_request import ActivityEventBindRequest
from smart_diagnostics_client.models.activity_event_bind_type import ActivityEventBindType
from smart_diagnostics_client.models.activity_event_category_child import ActivityEventCategoryChild
from smart_diagnostics_client.models.activity_event_category_flag import ActivityEventCategoryFlag
from smart_diagnostics_client.models.activity_event_category_owner_child import ActivityEventCategoryOwnerChild
from smart_diagnostics_client.models.activity_event_category_relationship_create_request import ActivityEventCategoryRelationshipCreateRequest
from smart_diagnostics_client.models.activity_event_category_relationship_response import ActivityEventCategoryRelationshipResponse
from smart_diagnostics_client.models.activity_event_category_response import ActivityEventCategoryResponse
from smart_diagnostics_client.models.activity_event_child import ActivityEventChild
from smart_diagnostics_client.models.activity_event_create_request import ActivityEventCreateRequest
from smart_diagnostics_client.models.activity_event_detail_response import ActivityEventDetailResponse
from smart_diagnostics_client.models.activity_event_document_request import ActivityEventDocumentRequest
from smart_diagnostics_client.models.activity_event_field_child import ActivityEventFieldChild
from smart_diagnostics_client.models.activity_event_field_entry_child import ActivityEventFieldEntryChild
from smart_diagnostics_client.models.activity_event_field_entry_request import ActivityEventFieldEntryRequest
from smart_diagnostics_client.models.activity_event_field_response import ActivityEventFieldResponse
from smart_diagnostics_client.models.activity_event_field_type import ActivityEventFieldType
from smart_diagnostics_client.models.activity_event_field_value_request import ActivityEventFieldValueRequest
from smart_diagnostics_client.models.activity_event_field_value_response import ActivityEventFieldValueResponse
from smart_diagnostics_client.models.activity_event_hierarchy_group_request import ActivityEventHierarchyGroupRequest
from smart_diagnostics_client.models.activity_event_hierarchy_group_response import ActivityEventHierarchyGroupResponse
from smart_diagnostics_client.models.activity_event_indicator_child import ActivityEventIndicatorChild
from smart_diagnostics_client.models.activity_event_owner_type import ActivityEventOwnerType
from smart_diagnostics_client.models.activity_event_relationship_child import ActivityEventRelationshipChild
from smart_diagnostics_client.models.activity_event_relationship_create_request import ActivityEventRelationshipCreateRequest
from smart_diagnostics_client.models.activity_event_relationship_response import ActivityEventRelationshipResponse
from smart_diagnostics_client.models.activity_event_relationship_type import ActivityEventRelationshipType
from smart_diagnostics_client.models.activity_event_response import ActivityEventResponse
from smart_diagnostics_client.models.activity_event_subcategory_child import ActivityEventSubcategoryChild
from smart_diagnostics_client.models.activity_event_subcategory_entry_request import ActivityEventSubcategoryEntryRequest
from smart_diagnostics_client.models.activity_event_subcategory_response import ActivityEventSubcategoryResponse
from smart_diagnostics_client.models.activity_event_update_request import ActivityEventUpdateRequest
from smart_diagnostics_client.models.alarm_definition_child import AlarmDefinitionChild
from smart_diagnostics_client.models.alert_acknowledgement_request import AlertAcknowledgementRequest
from smart_diagnostics_client.models.analytics_log_response import AnalyticsLogResponse
from smart_diagnostics_client.models.analytics_model_child import AnalyticsModelChild
from smart_diagnostics_client.models.analytics_model_create_request import AnalyticsModelCreateRequest
from smart_diagnostics_client.models.analytics_model_error_type_codes import AnalyticsModelErrorTypeCodes
from smart_diagnostics_client.models.analytics_model_indicator_child import AnalyticsModelIndicatorChild
from smart_diagnostics_client.models.analytics_model_response import AnalyticsModelResponse
from smart_diagnostics_client.models.analytics_model_status_update_request import AnalyticsModelStatusUpdateRequest
from smart_diagnostics_client.models.analytics_model_trigger_type import AnalyticsModelTriggerType
from smart_diagnostics_client.models.analytics_model_update_request import AnalyticsModelUpdateRequest
from smart_diagnostics_client.models.application_role_code import ApplicationRoleCode
from smart_diagnostics_client.models.asset_category_child import AssetCategoryChild
from smart_diagnostics_client.models.asset_category_create_request import AssetCategoryCreateRequest
from smart_diagnostics_client.models.asset_category_marker_child import AssetCategoryMarkerChild
from smart_diagnostics_client.models.asset_category_parameter_child import AssetCategoryParameterChild
from smart_diagnostics_client.models.asset_category_parameter_response import AssetCategoryParameterResponse
from smart_diagnostics_client.models.asset_category_parameter_type import AssetCategoryParameterType
from smart_diagnostics_client.models.asset_category_parameter_update_request import AssetCategoryParameterUpdateRequest
from smart_diagnostics_client.models.asset_category_parent_child import AssetCategoryParentChild
from smart_diagnostics_client.models.asset_category_response import AssetCategoryResponse
from smart_diagnostics_client.models.asset_category_type_response import AssetCategoryTypeResponse
from smart_diagnostics_client.models.asset_category_update_request import AssetCategoryUpdateRequest
from smart_diagnostics_client.models.asset_category_with_size_child import AssetCategoryWithSizeChild
from smart_diagnostics_client.models.asset_classification_assignment_response import AssetClassificationAssignmentResponse
from smart_diagnostics_client.models.asset_classification_assignment_update_request import AssetClassificationAssignmentUpdateRequest
from smart_diagnostics_client.models.asset_classification_category_child import AssetClassificationCategoryChild
from smart_diagnostics_client.models.asset_classification_parameter_value_child import AssetClassificationParameterValueChild
from smart_diagnostics_client.models.asset_classification_type_create_request import AssetClassificationTypeCreateRequest
from smart_diagnostics_client.models.asset_classification_type_update_request import AssetClassificationTypeUpdateRequest
from smart_diagnostics_client.models.asset_create_request import AssetCreateRequest
from smart_diagnostics_client.models.asset_criticality_child import AssetCriticalityChild
from smart_diagnostics_client.models.asset_drum_roll_child import AssetDrumRollChild
from smart_diagnostics_client.models.asset_economics_child import AssetEconomicsChild
from smart_diagnostics_client.models.asset_parameter_category_child import AssetParameterCategoryChild
from smart_diagnostics_client.models.asset_response import AssetResponse
from smart_diagnostics_client.models.asset_running_speed_child import AssetRunningSpeedChild
from smart_diagnostics_client.models.asset_running_speed_type import AssetRunningSpeedType
from smart_diagnostics_client.models.asset_size_child import AssetSizeChild
from smart_diagnostics_client.models.asset_type_child import AssetTypeChild
from smart_diagnostics_client.models.asset_type_response import AssetTypeResponse
from smart_diagnostics_client.models.asset_update_request import AssetUpdateRequest
from smart_diagnostics_client.models.assets_status_count_child import AssetsStatusCountChild
from smart_diagnostics_client.models.assets_status_percentage_child import AssetsStatusPercentageChild
from smart_diagnostics_client.models.attachment_model_v3 import AttachmentModelV3
from smart_diagnostics_client.models.band_definition_child import BandDefinitionChild
from smart_diagnostics_client.models.base_station_child import BaseStationChild
from smart_diagnostics_client.models.base_station_create_request import BaseStationCreateRequest
from smart_diagnostics_client.models.base_station_node_child import BaseStationNodeChild
from smart_diagnostics_client.models.base_station_receiver_child import BaseStationReceiverChild
from smart_diagnostics_client.models.base_station_response import BaseStationResponse
from smart_diagnostics_client.models.base_station_update_request import BaseStationUpdateRequest
from smart_diagnostics_client.models.baseline_indicator_child import BaselineIndicatorChild
from smart_diagnostics_client.models.baseline_with_significant_digits_child import BaselineWithSignificantDigitsChild
from smart_diagnostics_client.models.bearing_child import BearingChild
from smart_diagnostics_client.models.bearing_response import BearingResponse
from smart_diagnostics_client.models.board_child import BoardChild
from smart_diagnostics_client.models.board_ticket_status_create_request import BoardTicketStatusCreateRequest
from smart_diagnostics_client.models.board_ticket_status_update_request import BoardTicketStatusUpdateRequest
from smart_diagnostics_client.models.bulletin_response import BulletinResponse
from smart_diagnostics_client.models.bulletin_update_request import BulletinUpdateRequest
from smart_diagnostics_client.models.case_content_type_for_api import CaseContentTypeForApi
from smart_diagnostics_client.models.content_type import ContentType
from smart_diagnostics_client.models.content_type_hierarchy_level_enum import ContentTypeHierarchyLevelEnum
from smart_diagnostics_client.models.corporation_child import CorporationChild
from smart_diagnostics_client.models.corporation_create_request import CorporationCreateRequest
from smart_diagnostics_client.models.corporation_industry_child import CorporationIndustryChild
from smart_diagnostics_client.models.corporation_permission_create_request import CorporationPermissionCreateRequest
from smart_diagnostics_client.models.corporation_permission_update_request import CorporationPermissionUpdateRequest
from smart_diagnostics_client.models.corporation_response import CorporationResponse
from smart_diagnostics_client.models.corporation_update_request import CorporationUpdateRequest
from smart_diagnostics_client.models.corporation_user_role import CorporationUserRole
from smart_diagnostics_client.models.current_software_release_child import CurrentSoftwareReleaseChild
from smart_diagnostics_client.models.current_user_response import CurrentUserResponse
from smart_diagnostics_client.models.current_user_update_request import CurrentUserUpdateRequest
from smart_diagnostics_client.models.custom_marker_child import CustomMarkerChild
from smart_diagnostics_client.models.dashboard_create_request import DashboardCreateRequest
from smart_diagnostics_client.models.dashboard_permissions_update_request import DashboardPermissionsUpdateRequest
from smart_diagnostics_client.models.dashboard_response import DashboardResponse
from smart_diagnostics_client.models.dashboard_template_response import DashboardTemplateResponse
from smart_diagnostics_client.models.dashboard_type_child import DashboardTypeChild
from smart_diagnostics_client.models.dashboard_update_request import DashboardUpdateRequest
from smart_diagnostics_client.models.dashboard_widget_child import DashboardWidgetChild
from smart_diagnostics_client.models.dashboard_widget_request_child import DashboardWidgetRequestChild
from smart_diagnostics_client.models.descendant_child import DescendantChild
from smart_diagnostics_client.models.document_child import DocumentChild
from smart_diagnostics_client.models.enum_option_child_user_role_codes import EnumOptionChildUserRoleCodes
from smart_diagnostics_client.models.event_model_v3 import EventModelV3
from smart_diagnostics_client.models.external_notification_child import ExternalNotificationChild
from smart_diagnostics_client.models.external_notification_type import ExternalNotificationType
from smart_diagnostics_client.models.files_error import FilesError
from smart_diagnostics_client.models.files_update_request import FilesUpdateRequest
from smart_diagnostics_client.models.frequency_domain_setting_child import FrequencyDomainSettingChild
from smart_diagnostics_client.models.general_detail_error import GeneralDetailError
from smart_diagnostics_client.models.group_alerts_response import GroupAlertsResponse
from smart_diagnostics_client.models.group_analytics_model_add_request import GroupAnalyticsModelAddRequest
from smart_diagnostics_client.models.group_analytics_model_response import GroupAnalyticsModelResponse
from smart_diagnostics_client.models.group_analytics_model_update_request import GroupAnalyticsModelUpdateRequest
from smart_diagnostics_client.models.group_child import GroupChild
from smart_diagnostics_client.models.group_move_request import GroupMoveRequest
from smart_diagnostics_client.models.group_status_response import GroupStatusResponse
from smart_diagnostics_client.models.group_type_codes import GroupTypeCodes
from smart_diagnostics_client.models.group_type_codes_for_api import GroupTypeCodesForApi
from smart_diagnostics_client.models.hardware_event_model_v3 import HardwareEventModelV3
from smart_diagnostics_client.models.hardware_model_v3 import HardwareModelV3
from smart_diagnostics_client.models.hardware_revision_child import HardwareRevisionChild
from smart_diagnostics_client.models.hardware_status_child import HardwareStatusChild
from smart_diagnostics_client.models.hardware_status_response import HardwareStatusResponse
from smart_diagnostics_client.models.heatmap_aggregate_level import HeatmapAggregateLevel
from smart_diagnostics_client.models.heatmap_report_request import HeatmapReportRequest
from smart_diagnostics_client.models.hierarchy_child import HierarchyChild
from smart_diagnostics_client.models.hub_child import HubChild
from smart_diagnostics_client.models.hub_node_child import HubNodeChild
from smart_diagnostics_client.models.hub_overview_response import HubOverviewResponse
from smart_diagnostics_client.models.hub_port_child import HubPortChild
from smart_diagnostics_client.models.hub_power_type import HubPowerType
from smart_diagnostics_client.models.hub_response import HubResponse
from smart_diagnostics_client.models.hub_type import HubType
from smart_diagnostics_client.models.id_icon_body import IdIconBody
from smart_diagnostics_client.models.id_image_body import IdImageBody
from smart_diagnostics_client.models.identity_provider_create_request import IdentityProviderCreateRequest
from smart_diagnostics_client.models.identity_provider_response import IdentityProviderResponse
from smart_diagnostics_client.models.identity_provider_update_request import IdentityProviderUpdateRequest
from smart_diagnostics_client.models.indicator_alarm_state_response import IndicatorAlarmStateResponse
from smart_diagnostics_client.models.indicator_baseline_response import IndicatorBaselineResponse
from smart_diagnostics_client.models.indicator_filter_create_request import IndicatorFilterCreateRequest
from smart_diagnostics_client.models.indicator_filter_response import IndicatorFilterResponse
from smart_diagnostics_client.models.indicator_filter_update_request import IndicatorFilterUpdateRequest
from smart_diagnostics_client.models.indicator_group_create_request import IndicatorGroupCreateRequest
from smart_diagnostics_client.models.indicator_group_response import IndicatorGroupResponse
from smart_diagnostics_client.models.indicator_group_update_request import IndicatorGroupUpdateRequest
from smart_diagnostics_client.models.indicator_measure_of_code_child import IndicatorMeasureOfCodeChild
from smart_diagnostics_client.models.indicator_options_response import IndicatorOptionsResponse
from smart_diagnostics_client.models.indicator_response import IndicatorResponse
from smart_diagnostics_client.models.indicator_statistics_hierarchy_child import IndicatorStatisticsHierarchyChild
from smart_diagnostics_client.models.indicator_statistics_response import IndicatorStatisticsResponse
from smart_diagnostics_client.models.indicator_type_category_child import IndicatorTypeCategoryChild
from smart_diagnostics_client.models.indicator_types_response import IndicatorTypesResponse
from smart_diagnostics_client.models.install_add_user_response import InstallAddUserResponse
from smart_diagnostics_client.models.install_modify_users_request import InstallModifyUsersRequest
from smart_diagnostics_client.models.install_node_response import InstallNodeResponse
from smart_diagnostics_client.models.install_node_status_child import InstallNodeStatusChild
from smart_diagnostics_client.models.install_node_update_request import InstallNodeUpdateRequest
from smart_diagnostics_client.models.install_nodes_status_child import InstallNodesStatusChild
from smart_diagnostics_client.models.install_response import InstallResponse
from smart_diagnostics_client.models.install_update_request import InstallUpdateRequest
from smart_diagnostics_client.models.job_response import JobResponse
from smart_diagnostics_client.models.job_status import JobStatus
from smart_diagnostics_client.models.job_type import JobType
from smart_diagnostics_client.models.job_upload_error_response import JobUploadErrorResponse
from smart_diagnostics_client.models.json_patch_document import JsonPatchDocument
from smart_diagnostics_client.models.layout_child import LayoutChild
from smart_diagnostics_client.models.location_child import LocationChild
from smart_diagnostics_client.models.location_create_request import LocationCreateRequest
from smart_diagnostics_client.models.location_permission_create_request import LocationPermissionCreateRequest
from smart_diagnostics_client.models.location_permission_update_request import LocationPermissionUpdateRequest
from smart_diagnostics_client.models.location_permissions_response import LocationPermissionsResponse
from smart_diagnostics_client.models.location_permissions_update_request import LocationPermissionsUpdateRequest
from smart_diagnostics_client.models.location_response import LocationResponse
from smart_diagnostics_client.models.location_settings_child import LocationSettingsChild
from smart_diagnostics_client.models.location_update_request import LocationUpdateRequest
from smart_diagnostics_client.models.location_user_role import LocationUserRole
from smart_diagnostics_client.models.long_burst_request_child import LongBurstRequestChild
from smart_diagnostics_client.models.long_burst_request_state import LongBurstRequestState
from smart_diagnostics_client.models.marker_child import MarkerChild
from smart_diagnostics_client.models.marker_create_request import MarkerCreateRequest
from smart_diagnostics_client.models.marker_response import MarkerResponse
from smart_diagnostics_client.models.marker_type import MarkerType
from smart_diagnostics_client.models.marker_update_request import MarkerUpdateRequest
from smart_diagnostics_client.models.metric_classification_source_enum import MetricClassificationSourceEnum
from smart_diagnostics_client.models.metric_type_code_category import MetricTypeCodeCategory
from smart_diagnostics_client.models.metric_type_codes import MetricTypeCodes
from smart_diagnostics_client.models.model_id_source_body import ModelIdSourceBody
from smart_diagnostics_client.models.monitoring_point_assignment_response import MonitoringPointAssignmentResponse
from smart_diagnostics_client.models.monitoring_point_child import MonitoringPointChild
from smart_diagnostics_client.models.monitoring_point_create_request import MonitoringPointCreateRequest
from smart_diagnostics_client.models.monitoring_point_node_child import MonitoringPointNodeChild
from smart_diagnostics_client.models.monitoring_point_overview_node_child import MonitoringPointOverviewNodeChild
from smart_diagnostics_client.models.monitoring_point_overview_response import MonitoringPointOverviewResponse
from smart_diagnostics_client.models.monitoring_point_response import MonitoringPointResponse
from smart_diagnostics_client.models.monitoring_point_type_code_model import MonitoringPointTypeCodeModel
from smart_diagnostics_client.models.monitoring_point_type_codes import MonitoringPointTypeCodes
from smart_diagnostics_client.models.monitoring_point_type_codes_for_api import MonitoringPointTypeCodesForApi
from smart_diagnostics_client.models.monitoring_point_update_request import MonitoringPointUpdateRequest
from smart_diagnostics_client.models.move_files_request import MoveFilesRequest
from smart_diagnostics_client.models.move_files_response import MoveFilesResponse
from smart_diagnostics_client.models.node_child import NodeChild
from smart_diagnostics_client.models.node_response import NodeResponse
from smart_diagnostics_client.models.node_setting_child import NodeSettingChild
from smart_diagnostics_client.models.node_setting_overview import NodeSettingOverview
from smart_diagnostics_client.models.node_setting_values import NodeSettingValues
from smart_diagnostics_client.models.node_status_child import NodeStatusChild
from smart_diagnostics_client.models.node_type_codes import NodeTypeCodes
from smart_diagnostics_client.models.operation import Operation
from smart_diagnostics_client.models.option_child import OptionChild
from smart_diagnostics_client.models.option_model import OptionModel
from smart_diagnostics_client.models.overview_hierarchy_child import OverviewHierarchyChild
from smart_diagnostics_client.models.paged_results_model_activity_event_category_response import PagedResultsModelActivityEventCategoryResponse
from smart_diagnostics_client.models.paged_results_model_activity_event_hierarchy_group_response import PagedResultsModelActivityEventHierarchyGroupResponse
from smart_diagnostics_client.models.paged_results_model_activity_event_response import PagedResultsModelActivityEventResponse
from smart_diagnostics_client.models.paged_results_model_analytics_log_response import PagedResultsModelAnalyticsLogResponse
from smart_diagnostics_client.models.paged_results_model_analytics_model_response import PagedResultsModelAnalyticsModelResponse
from smart_diagnostics_client.models.paged_results_model_asset_category_response import PagedResultsModelAssetCategoryResponse
from smart_diagnostics_client.models.paged_results_model_asset_category_type_response import PagedResultsModelAssetCategoryTypeResponse
from smart_diagnostics_client.models.paged_results_model_asset_response import PagedResultsModelAssetResponse
from smart_diagnostics_client.models.paged_results_model_asset_type_response import PagedResultsModelAssetTypeResponse
from smart_diagnostics_client.models.paged_results_model_base_station_response import PagedResultsModelBaseStationResponse
from smart_diagnostics_client.models.paged_results_model_bearing_response import PagedResultsModelBearingResponse
from smart_diagnostics_client.models.paged_results_model_bulletin_response import PagedResultsModelBulletinResponse
from smart_diagnostics_client.models.paged_results_model_corporation_response import PagedResultsModelCorporationResponse
from smart_diagnostics_client.models.paged_results_model_dashboard_response import PagedResultsModelDashboardResponse
from smart_diagnostics_client.models.paged_results_model_dashboard_template_response import PagedResultsModelDashboardTemplateResponse
from smart_diagnostics_client.models.paged_results_model_group_alerts_response import PagedResultsModelGroupAlertsResponse
from smart_diagnostics_client.models.paged_results_model_group_analytics_model_response import PagedResultsModelGroupAnalyticsModelResponse
from smart_diagnostics_client.models.paged_results_model_group_status_response import PagedResultsModelGroupStatusResponse
from smart_diagnostics_client.models.paged_results_model_hardware_event_model_v3 import PagedResultsModelHardwareEventModelV3
from smart_diagnostics_client.models.paged_results_model_hub_overview_response import PagedResultsModelHubOverviewResponse
from smart_diagnostics_client.models.paged_results_model_hub_response import PagedResultsModelHubResponse
from smart_diagnostics_client.models.paged_results_model_identity_provider_response import PagedResultsModelIdentityProviderResponse
from smart_diagnostics_client.models.paged_results_model_indicator_baseline_response import PagedResultsModelIndicatorBaselineResponse
from smart_diagnostics_client.models.paged_results_model_indicator_filter_response import PagedResultsModelIndicatorFilterResponse
from smart_diagnostics_client.models.paged_results_model_indicator_group_response import PagedResultsModelIndicatorGroupResponse
from smart_diagnostics_client.models.paged_results_model_indicator_response import PagedResultsModelIndicatorResponse
from smart_diagnostics_client.models.paged_results_model_indicator_statistics_response import PagedResultsModelIndicatorStatisticsResponse
from smart_diagnostics_client.models.paged_results_model_install_node_response import PagedResultsModelInstallNodeResponse
from smart_diagnostics_client.models.paged_results_model_install_response import PagedResultsModelInstallResponse
from smart_diagnostics_client.models.paged_results_model_location_response import PagedResultsModelLocationResponse
from smart_diagnostics_client.models.paged_results_model_monitoring_point_assignment_response import PagedResultsModelMonitoringPointAssignmentResponse
from smart_diagnostics_client.models.paged_results_model_monitoring_point_overview_response import PagedResultsModelMonitoringPointOverviewResponse
from smart_diagnostics_client.models.paged_results_model_monitoring_point_response import PagedResultsModelMonitoringPointResponse
from smart_diagnostics_client.models.paged_results_model_node_response import PagedResultsModelNodeResponse
from smart_diagnostics_client.models.paged_results_model_personal_access_token_response import PagedResultsModelPersonalAccessTokenResponse
from smart_diagnostics_client.models.paged_results_model_picture_file_metadata_response import PagedResultsModelPictureFileMetadataResponse
from smart_diagnostics_client.models.paged_results_model_pictures_model_v3 import PagedResultsModelPicturesModelV3
from smart_diagnostics_client.models.paged_results_model_property_response import PagedResultsModelPropertyResponse
from smart_diagnostics_client.models.paged_results_model_receiver_response import PagedResultsModelReceiverResponse
from smart_diagnostics_client.models.paged_results_model_repeater_response import PagedResultsModelRepeaterResponse
from smart_diagnostics_client.models.paged_results_model_sensor_role_response import PagedResultsModelSensorRoleResponse
from smart_diagnostics_client.models.paged_results_model_sub_system_response import PagedResultsModelSubSystemResponse
from smart_diagnostics_client.models.paged_results_model_system_assets_status_summary_response import PagedResultsModelSystemAssetsStatusSummaryResponse
from smart_diagnostics_client.models.paged_results_model_system_overview_response import PagedResultsModelSystemOverviewResponse
from smart_diagnostics_client.models.paged_results_model_system_response import PagedResultsModelSystemResponse
from smart_diagnostics_client.models.paged_results_model_tag_response import PagedResultsModelTagResponse
from smart_diagnostics_client.models.paged_results_model_thermal_camera_region_response import PagedResultsModelThermalCameraRegionResponse
from smart_diagnostics_client.models.paged_results_model_thermal_camera_response import PagedResultsModelThermalCameraResponse
from smart_diagnostics_client.models.paged_results_model_ticket_response import PagedResultsModelTicketResponse
from smart_diagnostics_client.models.paged_results_model_tree_item_available_asset_class_response import PagedResultsModelTreeItemAvailableAssetClassResponse
from smart_diagnostics_client.models.paged_results_model_tree_item_response import PagedResultsModelTreeItemResponse
from smart_diagnostics_client.models.paged_results_model_user_response import PagedResultsModelUserResponse
from smart_diagnostics_client.models.parent_child import ParentChild
from smart_diagnostics_client.models.patch_request import PatchRequest
from smart_diagnostics_client.models.personal_access_token_create_request import PersonalAccessTokenCreateRequest
from smart_diagnostics_client.models.personal_access_token_create_response import PersonalAccessTokenCreateResponse
from smart_diagnostics_client.models.personal_access_token_response import PersonalAccessTokenResponse
from smart_diagnostics_client.models.personal_access_token_update_request import PersonalAccessTokenUpdateRequest
from smart_diagnostics_client.models.picture_file_metadata_response import PictureFileMetadataResponse
from smart_diagnostics_client.models.pictures_model_v3 import PicturesModelV3
from smart_diagnostics_client.models.power_bi_error import PowerBiError
from smart_diagnostics_client.models.power_bi_report_child import PowerBiReportChild
from smart_diagnostics_client.models.primary_corporation_child import PrimaryCorporationChild
from smart_diagnostics_client.models.problem_details import ProblemDetails
from smart_diagnostics_client.models.profile_child import ProfileChild
from smart_diagnostics_client.models.profile_options_response import ProfileOptionsResponse
from smart_diagnostics_client.models.property_child import PropertyChild
from smart_diagnostics_client.models.property_request_child import PropertyRequestChild
from smart_diagnostics_client.models.property_response import PropertyResponse
from smart_diagnostics_client.models.property_value_type import PropertyValueType
from smart_diagnostics_client.models.receiver_child import ReceiverChild
from smart_diagnostics_client.models.receiver_location_type_codes import ReceiverLocationTypeCodes
from smart_diagnostics_client.models.receiver_response import ReceiverResponse
from smart_diagnostics_client.models.receiver_type_codes import ReceiverTypeCodes
from smart_diagnostics_client.models.release_ring_child import ReleaseRingChild
from smart_diagnostics_client.models.repeater_child import RepeaterChild
from smart_diagnostics_client.models.repeater_node_child import RepeaterNodeChild
from smart_diagnostics_client.models.repeater_response import RepeaterResponse
from smart_diagnostics_client.models.roi_response import RoiResponse
from smart_diagnostics_client.models.sensor_role_response import SensorRoleResponse
from smart_diagnostics_client.models.sensor_role_type_codes import SensorRoleTypeCodes
from smart_diagnostics_client.models.session_create_request import SessionCreateRequest
from smart_diagnostics_client.models.session_indicator_type_child import SessionIndicatorTypeChild
from smart_diagnostics_client.models.session_measure_of_child import SessionMeasureOfChild
from smart_diagnostics_client.models.session_response import SessionResponse
from smart_diagnostics_client.models.session_selected_point_child import SessionSelectedPointChild
from smart_diagnostics_client.models.session_time_range_child import SessionTimeRangeChild
from smart_diagnostics_client.models.set_property_child import SetPropertyChild
from smart_diagnostics_client.models.setup_tools_job_type_body import SetupToolsJobTypeBody
from smart_diagnostics_client.models.smart_alarms_request import SmartAlarmsRequest
from smart_diagnostics_client.models.spectrum_chart_settings_create_request import SpectrumChartSettingsCreateRequest
from smart_diagnostics_client.models.spectrum_chart_settings_response import SpectrumChartSettingsResponse
from smart_diagnostics_client.models.statistics_report_request import StatisticsReportRequest
from smart_diagnostics_client.models.status_child import StatusChild
from smart_diagnostics_client.models.status_response import StatusResponse
from smart_diagnostics_client.models.sub_system_create_request import SubSystemCreateRequest
from smart_diagnostics_client.models.sub_system_response import SubSystemResponse
from smart_diagnostics_client.models.sub_system_update_request import SubSystemUpdateRequest
from smart_diagnostics_client.models.system_assets_status_summary_response import SystemAssetsStatusSummaryResponse
from smart_diagnostics_client.models.system_child import SystemChild
from smart_diagnostics_client.models.system_create_request import SystemCreateRequest
from smart_diagnostics_client.models.system_overview_response import SystemOverviewResponse
from smart_diagnostics_client.models.system_response import SystemResponse
from smart_diagnostics_client.models.system_update_request import SystemUpdateRequest
from smart_diagnostics_client.models.tag_categories import TagCategories
from smart_diagnostics_client.models.tag_child import TagChild
from smart_diagnostics_client.models.tag_create_request import TagCreateRequest
from smart_diagnostics_client.models.tag_response import TagResponse
from smart_diagnostics_client.models.tag_update_request import TagUpdateRequest
from smart_diagnostics_client.models.targeted_software_release_child import TargetedSoftwareReleaseChild
from smart_diagnostics_client.models.thermal_camera_create_request import ThermalCameraCreateRequest
from smart_diagnostics_client.models.thermal_camera_image_response import ThermalCameraImageResponse
from smart_diagnostics_client.models.thermal_camera_region_create_request import ThermalCameraRegionCreateRequest
from smart_diagnostics_client.models.thermal_camera_region_location_child import ThermalCameraRegionLocationChild
from smart_diagnostics_client.models.thermal_camera_region_response import ThermalCameraRegionResponse
from smart_diagnostics_client.models.thermal_camera_region_update_request import ThermalCameraRegionUpdateRequest
from smart_diagnostics_client.models.thermal_camera_response import ThermalCameraResponse
from smart_diagnostics_client.models.thermal_camera_settings_child import ThermalCameraSettingsChild
from smart_diagnostics_client.models.thermal_camera_settings_create_request import ThermalCameraSettingsCreateRequest
from smart_diagnostics_client.models.thermal_camera_settings_update_request import ThermalCameraSettingsUpdateRequest
from smart_diagnostics_client.models.thermal_camera_update_request import ThermalCameraUpdateRequest
from smart_diagnostics_client.models.ticket_create_request import TicketCreateRequest
from smart_diagnostics_client.models.ticket_response import TicketResponse
from smart_diagnostics_client.models.ticket_update_request import TicketUpdateRequest
from smart_diagnostics_client.models.time_range_model_v3 import TimeRangeModelV3
from smart_diagnostics_client.models.token_exchange_request import TokenExchangeRequest
from smart_diagnostics_client.models.token_exchange_response import TokenExchangeResponse
from smart_diagnostics_client.models.tree_item_available_asset_class_response import TreeItemAvailableAssetClassResponse
from smart_diagnostics_client.models.tree_item_child import TreeItemChild
from smart_diagnostics_client.models.tree_item_descendant_child import TreeItemDescendantChild
from smart_diagnostics_client.models.tree_item_response import TreeItemResponse
from smart_diagnostics_client.models.trigger_child import TriggerChild
from smart_diagnostics_client.models.update_bearings_for_group_request import UpdateBearingsForGroupRequest
from smart_diagnostics_client.models.user_child import UserChild
from smart_diagnostics_client.models.user_confirm_password_request import UserConfirmPasswordRequest
from smart_diagnostics_client.models.user_corporation_child import UserCorporationChild
from smart_diagnostics_client.models.user_create_request import UserCreateRequest
from smart_diagnostics_client.models.user_location_child import UserLocationChild
from smart_diagnostics_client.models.user_permissions_options_response import UserPermissionsOptionsResponse
from smart_diagnostics_client.models.user_phone_number_confirm_request import UserPhoneNumberConfirmRequest
from smart_diagnostics_client.models.user_profile_response import UserProfileResponse
from smart_diagnostics_client.models.user_profile_update_request import UserProfileUpdateRequest
from smart_diagnostics_client.models.user_request_corporation_child import UserRequestCorporationChild
from smart_diagnostics_client.models.user_request_location_child import UserRequestLocationChild
from smart_diagnostics_client.models.user_response import UserResponse
from smart_diagnostics_client.models.user_role_codes import UserRoleCodes
from smart_diagnostics_client.models.user_update_request import UserUpdateRequest
from smart_diagnostics_client.models.v30_bulletins_body import V30BulletinsBody
from smart_diagnostics_client.models.v30_files_body import V30FilesBody
from smart_diagnostics_client.models.validation_problem_details import ValidationProblemDetails
from smart_diagnostics_client.models.widget_child import WidgetChild
from smart_diagnostics_client.models.widget_code import WidgetCode
from smart_diagnostics_client.models.widget_template_child import WidgetTemplateChild
from smart_diagnostics_client.models.widget_template_filter_child import WidgetTemplateFilterChild
from smart_diagnostics_client.models.widget_time_range_values import WidgetTimeRangeValues
from smart_diagnostics_client.models.widget_type import WidgetType
from smart_diagnostics_client.models.widget_type_child import WidgetTypeChild
