# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.reports_api import ReportsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestReportsApi(unittest.TestCase):
    """ReportsApi unit test stubs"""

    def setUp(self):
        self.api = ReportsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_request_base_station_report(self):
        """Test case for request_base_station_report

        This will download a base station and repeater hardware report for the locations provided in the details model  # noqa: E501
        """
        pass

    def test_request_heatmap_report(self):
        """Test case for request_heatmap_report

        Enqueues a job to run and later email a heatmap report for the group provided using the options provided  # noqa: E501
        """
        pass

    def test_request_low_battery_report(self):
        """Test case for request_low_battery_report

        This will download a low battery report for the location provided in the details model  # noqa: E501
        """
        pass

    def test_request_statistics_report(self):
        """Test case for request_statistics_report

        Emails a statistics report for the group provided using the options provided  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
