# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.files_api import FilesApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestFilesApi(unittest.TestCase):
    """FilesApi unit test stubs"""

    def setUp(self):
        self.api = FilesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_file(self):
        """Test case for create_file

        Creates a file  # noqa: E501
        """
        pass

    def test_delete_file(self):
        """Test case for delete_file

        Deletes a file  # noqa: E501
        """
        pass

    def test_get_corporation_files(self):
        """Test case for get_corporation_files

        Gets all files for a corporation  # noqa: E501
        """
        pass

    def test_get_file(self):
        """Test case for get_file

        Gets a file  # noqa: E501
        """
        pass

    def test_get_file_object(self):
        """Test case for get_file_object

        Gets a file object  # noqa: E501
        """
        pass

    def test_get_files(self):
        """Test case for get_files

        Get all the files  # noqa: E501
        """
        pass

    def test_get_location_files(self):
        """Test case for get_location_files

        Gets all files for a location  # noqa: E501
        """
        pass

    def test_move_files(self):
        """Test case for move_files

        Moves files to a folder  # noqa: E501
        """
        pass

    def test_update_file(self):
        """Test case for update_file

        Update a file  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
