# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TagResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'active': 'bool',
        'type': 'TagCategories',
        'is_global': 'bool',
        'created': 'datetime',
        'updated': 'datetime',
        'location': 'LocationChild'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'active': 'Active',
        'type': 'Type',
        'is_global': 'IsGlobal',
        'created': 'Created',
        'updated': 'Updated',
        'location': 'Location'
    }

    def __init__(self, id=None, name=None, active=None, type=None, is_global=None, created=None, updated=None, location=None):  # noqa: E501
        """TagResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._active = None
        self._type = None
        self._is_global = None
        self._created = None
        self._updated = None
        self._location = None
        self.discriminator = None
        self.id = id
        self.name = name
        self.active = active
        self.type = type
        if is_global is not None:
            self.is_global = is_global
        self.created = created
        self.updated = updated
        if location is not None:
            self.location = location

    @property
    def id(self):
        """Gets the id of this TagResponse.  # noqa: E501

        Id of the tag  # noqa: E501

        :return: The id of this TagResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TagResponse.

        Id of the tag  # noqa: E501

        :param id: The id of this TagResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this TagResponse.  # noqa: E501

        Name of the tag  # noqa: E501

        :return: The name of this TagResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TagResponse.

        Name of the tag  # noqa: E501

        :param name: The name of this TagResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def active(self):
        """Gets the active of this TagResponse.  # noqa: E501

        Indicates if a tag is active  # noqa: E501

        :return: The active of this TagResponse.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this TagResponse.

        Indicates if a tag is active  # noqa: E501

        :param active: The active of this TagResponse.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def type(self):
        """Gets the type of this TagResponse.  # noqa: E501


        :return: The type of this TagResponse.  # noqa: E501
        :rtype: TagCategories
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this TagResponse.


        :param type: The type of this TagResponse.  # noqa: E501
        :type: TagCategories
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def is_global(self):
        """Gets the is_global of this TagResponse.  # noqa: E501

        Indicates if tag is global  # noqa: E501

        :return: The is_global of this TagResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_global

    @is_global.setter
    def is_global(self, is_global):
        """Sets the is_global of this TagResponse.

        Indicates if tag is global  # noqa: E501

        :param is_global: The is_global of this TagResponse.  # noqa: E501
        :type: bool
        """

        self._is_global = is_global

    @property
    def created(self):
        """Gets the created of this TagResponse.  # noqa: E501

        Date tag was created  # noqa: E501

        :return: The created of this TagResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this TagResponse.

        Date tag was created  # noqa: E501

        :param created: The created of this TagResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this TagResponse.  # noqa: E501

        Date tag was updated  # noqa: E501

        :return: The updated of this TagResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this TagResponse.

        Date tag was updated  # noqa: E501

        :param updated: The updated of this TagResponse.  # noqa: E501
        :type: datetime
        """
        if updated is None:
            raise ValueError("Invalid value for `updated`, must not be `None`")  # noqa: E501

        self._updated = updated

    @property
    def location(self):
        """Gets the location of this TagResponse.  # noqa: E501


        :return: The location of this TagResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this TagResponse.


        :param location: The location of this TagResponse.  # noqa: E501
        :type: LocationChild
        """

        self._location = location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TagResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TagResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
