# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.users_api import UsersApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_corporation_permission(self):
        """Test case for add_corporation_permission

        """
        pass

    def test_add_location_permission(self):
        """Test case for add_location_permission

        Adds a location permission for the specified user  # noqa: E501
        """
        pass

    def test_check_email_exists(self):
        """Test case for check_email_exists

        Checks if the given email exists  # noqa: E501
        """
        pass

    def test_confirm_password_sd4(self):
        """Test case for confirm_password_sd4

        Confirms a user's new password when user resets their password.  # noqa: E501
        """
        pass

    def test_create_user(self):
        """Test case for create_user

        Create a new user  # noqa: E501
        """
        pass

    def test_delete_corporation_permission(self):
        """Test case for delete_corporation_permission

        Deletes a specific corporation permission  # noqa: E501
        """
        pass

    def test_delete_location_permission(self):
        """Test case for delete_location_permission

        Deletes a specific location permission  # noqa: E501
        """
        pass

    def test_delete_personal_access_token(self):
        """Test case for delete_personal_access_token

        Revokes one of the current user's access tokens.  # noqa: E501
        """
        pass

    def test_generate_personal_access_tokens(self):
        """Test case for generate_personal_access_tokens

        Generate a new access token for the current user.  # noqa: E501
        """
        pass

    def test_get_current_user(self):
        """Test case for get_current_user

        Gets the Current user  # noqa: E501
        """
        pass

    def test_get_personal_access_token(self):
        """Test case for get_personal_access_token

        Get one of the current user's access tokens.  # noqa: E501
        """
        pass

    def test_get_personal_access_tokens(self):
        """Test case for get_personal_access_tokens

        Lists the current user's access tokens.  # noqa: E501
        """
        pass

    def test_get_profile_options(self):
        """Test case for get_profile_options

        Gets all possible options for user profile properties  # noqa: E501
        """
        pass

    def test_get_user(self):
        """Test case for get_user

        Returns a specified user  # noqa: E501
        """
        pass

    def test_get_user_locations(self):
        """Test case for get_user_locations

        Returns a paged list of all locations that the selected user and accessing user both have access to  # noqa: E501
        """
        pass

    def test_get_user_profile(self):
        """Test case for get_user_profile

        Gets a user's profile  # noqa: E501
        """
        pass

    def test_get_users(self):
        """Test case for get_users

        Returns a paged list of all users  # noqa: E501
        """
        pass

    def test_reset_password_sd4(self):
        """Test case for reset_password_sd4

        Requests that a users password be reset. The users will receive an email with  instructions on how to reset their password.  # noqa: E501
        """
        pass

    def test_send_confirmation_code(self):
        """Test case for send_confirmation_code

        Sends a confirmation code to the supplied phone number  # noqa: E501
        """
        pass

    def test_unlock_user(self):
        """Test case for unlock_user

        Unlocks the user with the specified id (Sets LockedOut to false)  # noqa: E501
        """
        pass

    def test_update_corporation_permission(self):
        """Test case for update_corporation_permission

        Updates an existing user's corporation permission  # noqa: E501
        """
        pass

    def test_update_current_user(self):
        """Test case for update_current_user

        Updates the current user's information.  # noqa: E501
        """
        pass

    def test_update_location_permission(self):
        """Test case for update_location_permission

        Updates an existing user location permission  # noqa: E501
        """
        pass

    def test_update_personal_access_token(self):
        """Test case for update_personal_access_token

        Update one of the current user's access tokens.  # noqa: E501
        """
        pass

    def test_update_user(self):
        """Test case for update_user

        Updates a user  # noqa: E501
        """
        pass

    def test_update_user_profile(self):
        """Test case for update_user_profile

        Updates a user's profile  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
