# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.documents_api import DocumentsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestDocumentsApi(unittest.TestCase):
    """DocumentsApi unit test stubs"""

    def setUp(self):
        self.api = DocumentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_generate_signed_user_manual_link(self):
        """Test case for generate_signed_user_manual_link

        Returns a temporary signed link to the User Manual from S3.  # noqa: E501
        """
        pass

    def test_get_manual_file(self):
        """Test case for get_manual_file

        Returns the User Manual as a pdf file.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
