# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.installs_api import InstallsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestInstallsApi(unittest.TestCase):
    """InstallsApi unit test stubs"""

    def setUp(self):
        self.api = InstallsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_users_to_install(self):
        """Test case for add_users_to_install

        Adds one or more users to an install  # noqa: E501
        """
        pass

    def test_export_install_report(self):
        """Test case for export_install_report

        Triggers a Hangfire job that will email an install's status report to the user  # noqa: E501
        """
        pass

    def test_get_install(self):
        """Test case for get_install

        Gets a single Install  # noqa: E501
        """
        pass

    def test_get_installs(self):
        """Test case for get_installs

        Gets a list of installs for the current user  # noqa: E501
        """
        pass

    def test_get_node_install_status(self):
        """Test case for get_node_install_status

        Gets a list of nodes per install  # noqa: E501
        """
        pass

    def test_remove_users_from_install(self):
        """Test case for remove_users_from_install

        Removes one or more users from an install  # noqa: E501
        """
        pass

    def test_update_install(self):
        """Test case for update_install

        Updates properties related to an install  # noqa: E501
        """
        pass

    def test_update_node_install_status(self):
        """Test case for update_node_install_status

        Updates a node's status for the install  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
