# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.repeaters_api import RepeatersApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestRepeatersApi(unittest.TestCase):
    """RepeatersApi unit test stubs"""

    def setUp(self):
        self.api = RepeatersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_export_repeaters(self):
        """Test case for export_repeaters

        Requests a Repeater export.  # noqa: E501
        """
        pass

    def test_get_repeater_overview(self):
        """Test case for get_repeater_overview

        Gets a single repeater overview  # noqa: E501
        """
        pass

    def test_get_repeaters_overview(self):
        """Test case for get_repeaters_overview

        Gets repeaters  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
