# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MonitoringPointOverviewResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'monitoring_point_type': 'MonitoringPointTypeCodes',
        'is_paused': 'bool',
        'is_snoozed': 'bool',
        'running_speed_multiplier': 'float',
        'node': 'MonitoringPointOverviewNodeChild',
        'hierarchy': 'list[OverviewHierarchyChild]',
        'node_settings': 'NodeSettingOverview',
        'bearing_assignment': 'BearingChild'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'monitoring_point_type': 'MonitoringPointType',
        'is_paused': 'IsPaused',
        'is_snoozed': 'IsSnoozed',
        'running_speed_multiplier': 'RunningSpeedMultiplier',
        'node': 'Node',
        'hierarchy': 'Hierarchy',
        'node_settings': 'NodeSettings',
        'bearing_assignment': 'BearingAssignment'
    }

    def __init__(self, id=None, name=None, monitoring_point_type=None, is_paused=None, is_snoozed=None, running_speed_multiplier=None, node=None, hierarchy=None, node_settings=None, bearing_assignment=None):  # noqa: E501
        """MonitoringPointOverviewResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._monitoring_point_type = None
        self._is_paused = None
        self._is_snoozed = None
        self._running_speed_multiplier = None
        self._node = None
        self._hierarchy = None
        self._node_settings = None
        self._bearing_assignment = None
        self.discriminator = None
        self.id = id
        self.name = name
        if monitoring_point_type is not None:
            self.monitoring_point_type = monitoring_point_type
        self.is_paused = is_paused
        self.is_snoozed = is_snoozed
        if running_speed_multiplier is not None:
            self.running_speed_multiplier = running_speed_multiplier
        if node is not None:
            self.node = node
        if hierarchy is not None:
            self.hierarchy = hierarchy
        if node_settings is not None:
            self.node_settings = node_settings
        if bearing_assignment is not None:
            self.bearing_assignment = bearing_assignment

    @property
    def id(self):
        """Gets the id of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The id of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MonitoringPointOverviewResponse.


        :param id: The id of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The name of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MonitoringPointOverviewResponse.


        :param name: The name of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def monitoring_point_type(self):
        """Gets the monitoring_point_type of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The monitoring_point_type of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: MonitoringPointTypeCodes
        """
        return self._monitoring_point_type

    @monitoring_point_type.setter
    def monitoring_point_type(self, monitoring_point_type):
        """Sets the monitoring_point_type of this MonitoringPointOverviewResponse.


        :param monitoring_point_type: The monitoring_point_type of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: MonitoringPointTypeCodes
        """

        self._monitoring_point_type = monitoring_point_type

    @property
    def is_paused(self):
        """Gets the is_paused of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The is_paused of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_paused

    @is_paused.setter
    def is_paused(self, is_paused):
        """Sets the is_paused of this MonitoringPointOverviewResponse.


        :param is_paused: The is_paused of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: bool
        """
        if is_paused is None:
            raise ValueError("Invalid value for `is_paused`, must not be `None`")  # noqa: E501

        self._is_paused = is_paused

    @property
    def is_snoozed(self):
        """Gets the is_snoozed of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The is_snoozed of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_snoozed

    @is_snoozed.setter
    def is_snoozed(self, is_snoozed):
        """Sets the is_snoozed of this MonitoringPointOverviewResponse.


        :param is_snoozed: The is_snoozed of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: bool
        """
        if is_snoozed is None:
            raise ValueError("Invalid value for `is_snoozed`, must not be `None`")  # noqa: E501

        self._is_snoozed = is_snoozed

    @property
    def running_speed_multiplier(self):
        """Gets the running_speed_multiplier of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The running_speed_multiplier of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: float
        """
        return self._running_speed_multiplier

    @running_speed_multiplier.setter
    def running_speed_multiplier(self, running_speed_multiplier):
        """Sets the running_speed_multiplier of this MonitoringPointOverviewResponse.


        :param running_speed_multiplier: The running_speed_multiplier of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: float
        """

        self._running_speed_multiplier = running_speed_multiplier

    @property
    def node(self):
        """Gets the node of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The node of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: MonitoringPointOverviewNodeChild
        """
        return self._node

    @node.setter
    def node(self, node):
        """Sets the node of this MonitoringPointOverviewResponse.


        :param node: The node of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: MonitoringPointOverviewNodeChild
        """

        self._node = node

    @property
    def hierarchy(self):
        """Gets the hierarchy of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The hierarchy of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: list[OverviewHierarchyChild]
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """Sets the hierarchy of this MonitoringPointOverviewResponse.


        :param hierarchy: The hierarchy of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: list[OverviewHierarchyChild]
        """

        self._hierarchy = hierarchy

    @property
    def node_settings(self):
        """Gets the node_settings of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The node_settings of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: NodeSettingOverview
        """
        return self._node_settings

    @node_settings.setter
    def node_settings(self, node_settings):
        """Sets the node_settings of this MonitoringPointOverviewResponse.


        :param node_settings: The node_settings of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: NodeSettingOverview
        """

        self._node_settings = node_settings

    @property
    def bearing_assignment(self):
        """Gets the bearing_assignment of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The bearing_assignment of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: BearingChild
        """
        return self._bearing_assignment

    @bearing_assignment.setter
    def bearing_assignment(self, bearing_assignment):
        """Sets the bearing_assignment of this MonitoringPointOverviewResponse.


        :param bearing_assignment: The bearing_assignment of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: BearingChild
        """

        self._bearing_assignment = bearing_assignment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MonitoringPointOverviewResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MonitoringPointOverviewResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
