# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MarkerResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'marker_type': 'MarkerType',
        'value': 'float',
        'order': 'int'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'marker_type': 'MarkerType',
        'value': 'Value',
        'order': 'Order'
    }

    def __init__(self, id=None, name=None, marker_type=None, value=None, order=None):  # noqa: E501
        """MarkerResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._marker_type = None
        self._value = None
        self._order = None
        self.discriminator = None
        self.id = id
        self.name = name
        self.marker_type = marker_type
        self.value = value
        self.order = order

    @property
    def id(self):
        """Gets the id of this MarkerResponse.  # noqa: E501


        :return: The id of this MarkerResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MarkerResponse.


        :param id: The id of this MarkerResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this MarkerResponse.  # noqa: E501


        :return: The name of this MarkerResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MarkerResponse.


        :param name: The name of this MarkerResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def marker_type(self):
        """Gets the marker_type of this MarkerResponse.  # noqa: E501


        :return: The marker_type of this MarkerResponse.  # noqa: E501
        :rtype: MarkerType
        """
        return self._marker_type

    @marker_type.setter
    def marker_type(self, marker_type):
        """Sets the marker_type of this MarkerResponse.


        :param marker_type: The marker_type of this MarkerResponse.  # noqa: E501
        :type: MarkerType
        """
        if marker_type is None:
            raise ValueError("Invalid value for `marker_type`, must not be `None`")  # noqa: E501

        self._marker_type = marker_type

    @property
    def value(self):
        """Gets the value of this MarkerResponse.  # noqa: E501


        :return: The value of this MarkerResponse.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this MarkerResponse.


        :param value: The value of this MarkerResponse.  # noqa: E501
        :type: float
        """
        if value is None:
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def order(self):
        """Gets the order of this MarkerResponse.  # noqa: E501


        :return: The order of this MarkerResponse.  # noqa: E501
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this MarkerResponse.


        :param order: The order of this MarkerResponse.  # noqa: E501
        :type: int
        """
        if order is None:
            raise ValueError("Invalid value for `order`, must not be `None`")  # noqa: E501

        self._order = order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MarkerResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MarkerResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
