# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class IdentityProviderResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'username_identifiers': 'list[str]',
        'corporation_child': 'PrimaryCorporationChild'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'username_identifiers': 'UsernameIdentifiers',
        'corporation_child': 'CorporationChild'
    }

    def __init__(self, id=None, name=None, username_identifiers=None, corporation_child=None):  # noqa: E501
        """IdentityProviderResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._username_identifiers = None
        self._corporation_child = None
        self.discriminator = None
        self.id = id
        if name is not None:
            self.name = name
        if username_identifiers is not None:
            self.username_identifiers = username_identifiers
        if corporation_child is not None:
            self.corporation_child = corporation_child

    @property
    def id(self):
        """Gets the id of this IdentityProviderResponse.  # noqa: E501

        ID  # noqa: E501

        :return: The id of this IdentityProviderResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IdentityProviderResponse.

        ID  # noqa: E501

        :param id: The id of this IdentityProviderResponse.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this IdentityProviderResponse.  # noqa: E501

        Name  # noqa: E501

        :return: The name of this IdentityProviderResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IdentityProviderResponse.

        Name  # noqa: E501

        :param name: The name of this IdentityProviderResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def username_identifiers(self):
        """Gets the username_identifiers of this IdentityProviderResponse.  # noqa: E501

        Username Identifier  # noqa: E501

        :return: The username_identifiers of this IdentityProviderResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._username_identifiers

    @username_identifiers.setter
    def username_identifiers(self, username_identifiers):
        """Sets the username_identifiers of this IdentityProviderResponse.

        Username Identifier  # noqa: E501

        :param username_identifiers: The username_identifiers of this IdentityProviderResponse.  # noqa: E501
        :type: list[str]
        """

        self._username_identifiers = username_identifiers

    @property
    def corporation_child(self):
        """Gets the corporation_child of this IdentityProviderResponse.  # noqa: E501


        :return: The corporation_child of this IdentityProviderResponse.  # noqa: E501
        :rtype: PrimaryCorporationChild
        """
        return self._corporation_child

    @corporation_child.setter
    def corporation_child(self, corporation_child):
        """Sets the corporation_child of this IdentityProviderResponse.


        :param corporation_child: The corporation_child of this IdentityProviderResponse.  # noqa: E501
        :type: PrimaryCorporationChild
        """

        self._corporation_child = corporation_child

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IdentityProviderResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IdentityProviderResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
